A GUI screener to help scan and evaluate the title and abstract of studies to be included in a systematic review or meta-analysis. A description of GUI options and layout is found here: http://lajeunesse.myweb.usf.edu/juicr/juicr_basic_vignette_v0.1.html.
GUI_juicr(
theFigureFile = "",
theJuicrFile = "",
standardizeTheImage = TRUE,
standardSize = 1000,
figureWindowSize = c(800, 600),
pointSize = 6,
animateDelay = TRUE,
groupNames = c("orangeGrp", "berryGrp", "cherryGrp", "plumGrp", "kiwiGrp", "bananaGrp",
"grapeGrp", "pruneGrp"),
groupColors = c("dark orange", "turquoise3", "tomato3", "orchid", "yellow green",
"goldenrod2", "plum4", "saddle brown")
)A console message of where saved .csv or *_juicr.html files are located.
An optional file name and location of a .jpg, .png, or .tiff file containing the scientific image/plot/chart/figure to pre-load in the GUI. Within the GUI there is also a button to select the image file. Images in other formats should be converted to .png prior to using juicr.
An optional file name and location of a *_juicr.html report containing extractions and images from a previous juicr session to pre-load into the GUI. Within the GUI there is also a button to select an .html file.
When "TRUE", all large images are
standardized to a common size with a width specified
by "standardSize". When "FALSE", the image is unaltered
in size.
The common width in pixels for standardizing large images; default is a width of 1000 pixels.
Specifies the window size containing the image. By default, this image-viewer window will be 800 (width) by 600 (height) pixels, larger images will be scrollable to fit this window.
Changes the default size of a clickable data-point on the image. Size is the radius in pixels (default is 6).
When "TRUE", creates a very small pause when
plotting individual automated extractions -- giving an animated effect.
A vector of the default eight names specifying the labels of each group. Default labels are fruit themed. Can be any size, but GUI will only print first 9 characters.
A vector of the default eight color names specifying the coloring of each group. Are in color-names format, but can also be HEX.
if (FALSE) {
GUI_juicr(system.file("images", "Kortum_and_Acymyan_2013_Fig4.jpg", package = "juicr"))
}
Run the code above in your browser using DataLab