Learn R Programming

juicr (version 0.2)

file_getJuicr_Extractions: Reads a *_juicr.html report and retrieves data extractions and history.

Description

Reads a juicr generated report of image extractions contained within the .html file.

Usage

file_getJuicr_Extractions(aFileName = file.choose(), quiet = FALSE)

Value

A list of tables including all extractions, coordinates, image file names, and juicr GUI parameters.

Arguments

aFileName

The file name and location of a *_juicr.html report. Prompts for file name if none is explicitly called. Must be .html format.

quiet

When "TRUE", does not display all extraction tables.

See Also

file_getJuicr_Images

Examples

Run this code
if (FALSE) {

theExtraction <- file_getJuicr_Extractions("pretend_image_juicr.html")
print(theExtraction$points)

}

Run the code above in your browser using DataLab