Learn R Programming

juicr (version 0.2)

file_getJuicr_Images: Reads a *_juicr.html report and extracts images into working directory.

Description

Reads a juicr generated report of image extractions contained within the .html file, and saves all images (e.g., original, standardized, and standardized with painted extractions).

Usage

file_getJuicr_Images(aFileName = file.choose(), quiet = FALSE)

Value

A vector of file names of each image extracted from the .html file.

Arguments

aFileName

The file name and location of a *_juicr.html report. Prompts for file name if none is explicitly called. Must be .html format.

quiet

When "TRUE", does not display the file names of all images extracted and saved to the working directory.

See Also

file_getJuicr_Extractions

Examples

Run this code
if (FALSE) {

file_getJuicr_Images("pretend_image_juicr.html")

}

Run the code above in your browser using DataLab