powered by
Reads a juicr generated report of image extractions contained within the .html file.
file_getJuicr_Extractions(aFileName = file.choose(), quiet = FALSE)
A list of tables including all extractions, coordinates, image file names, and juicr GUI parameters.
juicr
The file name and location of a *_juicr.html report. Prompts for file name if none is explicitly called. Must be .html format.
When "TRUE", does not display all extraction tables.
"TRUE"
file_getJuicr_Images
if (FALSE) { theExtraction <- file_getJuicr_Extractions("pretend_image_juicr.html") print(theExtraction$points) }
Run the code above in your browser using DataLab